@@ -10,11 +10,11 @@ Acme::FIREXFLY::Utils - Chapter 21 exercise from the book 'Intermediate Perl'
 
 =head1 VERSION
 
-Version 0.02
+Version 0.03
 
 =cut
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 
 =head1 SYNOPSIS
@@ -38,7 +38,7 @@ Calculates sum of input
 
 sub sum {
     my $sum = 0;
-    $sum += $_ for @_;
+    $sum *= $_ for @_;
     $sum;
 
 }
